@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/pkg/bin/python3.11",
 
         # Package versions
-        contourpy_version="1.3.0",
-        meson_version="1.5.2",
-        mesonpy_version="0.16.0",
+        contourpy_version="1.3.1",
+        meson_version="1.6.0",
+        mesonpy_version="0.17.1",
         pybind11_version="2.13.6",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/.mesonpy-q79mn6ob/lib/contourpy/util",
-        source_dir=r"/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/lib/contourpy/util",
+        build_dir=r"/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.1/.mesonpy-ucy0m_s0/lib/contourpy/util",
+        source_dir=r"/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/tmp/pkgbuild/graphics/py-contourpy/work.sparc64/contourpy-1.3.0/.mesonpy-q79mn6ob/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/pbulk/work/graphics/py-contourpy/work/contourpy-1.3.1/.mesonpy-ucy0m_s0/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,19 +42,19 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="7.5.0",
+        compiler_version="10.5.0",
         linker_id="ld.bfd",
         compile_command="c++",
 
         # Host machine
-        host_cpu="sparc64",
-        host_cpu_family="sparc64",
-        host_cpu_endian="big",
+        host_cpu="arm",
+        host_cpu_family="arm",
+        host_cpu_endian="little",
         host_cpu_system="netbsd",
 
         # Build machine, same as host machine if not a cross_build
-        build_cpu="sparc64",
-        build_cpu_family="sparc64",
-        build_cpu_endian="big",
+        build_cpu="arm",
+        build_cpu_family="arm",
+        build_cpu_endian="little",
         build_cpu_system="netbsd",
     )
